pub struct PageFinalizer;Expand description
Page finalizer for final output generation
Implementations
Sourceimpl PageFinalizer
impl PageFinalizer
Sourcepub fn finalize(
input_path: &Path,
output_path: &Path,
options: &FinalizeOptions,
crop_region: Option<CropRegion>,
shift_x: i32,
shift_y: i32,
) -> Result<FinalizeResult>
pub fn finalize( input_path: &Path, output_path: &Path, options: &FinalizeOptions, crop_region: Option<CropRegion>, shift_x: i32, shift_y: i32, ) -> Result<FinalizeResult>
Finalize a page with optional crop region and shift
Sourcepub fn finalize_batch(
pages: &[(PathBuf, PathBuf, bool)],
options: &FinalizeOptions,
odd_crop: Option<CropRegion>,
even_crop: Option<CropRegion>,
page_shifts: &[(i32, i32)],
) -> Result<Vec<FinalizeResult>>
pub fn finalize_batch( pages: &[(PathBuf, PathBuf, bool)], options: &FinalizeOptions, odd_crop: Option<CropRegion>, even_crop: Option<CropRegion>, page_shifts: &[(i32, i32)], ) -> Result<Vec<FinalizeResult>>
Finalize multiple pages with unified crop regions for odd/even groups